<?php
/**
 * Gutenify Store: Block Patterns
 *
 * @since Gutenify Store 1.0
 */

 /**
  * Get patterns content.
  *
  * @param string $file_name Filename.
  * @return string
  */
function gutenify_store_get_pattern_content( $file_name ) {
	ob_start();
	include get_theme_file_path( '/inc/patterns/' . $file_name . '.php' );
	$output = ob_get_contents();
	ob_end_clean();
	return $output;
}

/**
 * Registers block patterns and categories.
 *
 * @since Gutenify Store 1.0
 *
 * @return void
 */
function gutenify_store_register_block_patterns() {

	$patterns = array(
		'footer-default' => array(
			'title'      => __( 'Default footer', 'gutenify-store' ),
			'categories' => array( 'gutenify-store-footers' ),
			'blockTypes' => array( 'core/template-part/footer' ),
		),
		'header-default' => array(
			'title'      => __( 'Default header', 'gutenify-store' ),
			'categories' => array( 'gutenify-store-headers' ),
			'blockTypes' => array( 'core/template-part/header' ),
		),
		'post-listing' => array(
			'title'    => __( 'Post Listing', 'gutenify-store' ),
			'inserter' => false,
			'categories' => array( 'gutenify-store-query' ),
		),
		'hidden-404' => array(
			'title'    => __( '404 content', 'gutenify-store' ),
			'categories' => array( 'gutenify-store-pages' ),
		),
		'page-cover-title' => array(
			'title'    => __( 'Page Cover Title', 'gutenify-store' ),
			'categories' => array( 'featured' ),
		),
		'hero-section-1' => array(
			'title'    => __( 'Hero Section 1', 'gutenify-store' ),
			'categories' => array( 'gutenify-store-hero' ),
		),
		'media-text-1' => array(
			'title'    => __( 'Media Text 1', 'gutenify-store' ),
			'categories' => array( 'gutenify-store-media-text' ),
		),
		'cta-1' => array(
			'title'    => __( 'Media Text 1', 'gutenify-store' ),
			'categories' => array( 'gutenify-store-cta' ),
		),
	);

	$block_pattern_categories = array(
		'featured'                 => array( 'label' => __( 'Featured', 'gutenify-store' ) ),
		'gutenify-store-footers' => array( 'label' => __( 'Footers', 'gutenify-store' ) ),
		'gutenify-store-headers' => array( 'label' => __( 'Headers', 'gutenify-store' ) ),
		'gutenify-store-query'   => array( 'label' => __( 'Query', 'gutenify-store' ) ),
		'gutenify-store-pages'   => array( 'label' => __( 'Pages', 'gutenify-store' ) ),
		'gutenify-store-hero'   => array( 'label' => __( 'Hero Sections', 'gutenify-store' ) ),
		'gutenify-store-media-text'   => array( 'label' => __( 'Media Text', 'gutenify-store' ) ),
		'gutenify-store-cta'   => array( 'label' => __( 'CTA', 'gutenify-store' ) ),
	);

	/**
	 * Filters the theme block pattern categories.
	 *
	 * @since Gutenify Store 1.0
	 *
	 * @param array[] $block_pattern_categories {
	 *     An associative array of block pattern categories, keyed by category name.
	 *
	 *     @type array[] $properties {
	 *         An array of block category properties.
	 *
	 *         @type string $label A human-readable label for the pattern category.
	 *     }
	 * }
	 */
	$block_pattern_categories = apply_filters( 'gutenify_store_block_pattern_categories', $block_pattern_categories );

	foreach ( $block_pattern_categories as $name => $properties ) {
		if ( ! WP_Block_Pattern_Categories_Registry::get_instance()->is_registered( $name ) ) {
			register_block_pattern_category( $name, $properties );
		}
	}

	/**
	 * Filters the theme block patterns.
	 *
	 * @since Gutenify Store 1.0
	 *
	 * @param array $block_patterns List of block patterns by name.
	 */
	$patterns = apply_filters( 'gutenify_store_block_patterns', $patterns );

	foreach ( $patterns as $block_pattern => $pattern ) {
		$pattern['content'] = gutenify_store_get_pattern_content( $block_pattern );
		register_block_pattern(
			'gutenify-store/' . $block_pattern,
			$pattern
		);
	}
}
add_action( 'init', 'gutenify_store_register_block_patterns', 9 );
